@@ -1,6 +1,6 @@
 #' Creates the base cache folder where `tidywikidatar` caches data.
 #'
-#' @param ask Logical, defaults to TRUE. If FALSE, and cache folder does not exist, it just creates it without asking (useful for non-interactive sessions).
+#' @inheritParams tw_reset_item_cache
 #'
 #' @return Nothing, used for its side effects.
 #' @export
@@ -14,16 +14,24 @@
 tw_create_cache_folder <- function(ask = TRUE) {
   if (!fs::file_exists(tidywikidatar::tw_get_cache_folder())) {
     if (!ask) {
-      fs::dir_create(path = tidywikidatar::tw_get_cache_folder(), recurse = TRUE)
+      fs::dir_create(
+        path = tidywikidatar::tw_get_cache_folder(),
+        recurse = TRUE
+      )
     } else {
       cli::cli_inform(c(
         "The cache folder {.path {tw_get_cache_folder()}} does not exist.",
         "If you prefer to cache files elsewhere, reply no and set your preferred cache folder with {.fn tw_set_cache_folder}."
       ))
-      msg_yes_no <- cli::format_inline("Do you want to create {.path {tw_get_cache_folder()}} for caching data?")
+      msg_yes_no <- cli::format_inline(
+        "Do you want to create {.path {tw_get_cache_folder()}} for caching data?"
+      )
       check <- utils::menu(choices = c("Yes", "No"), title = msg_yes_no)
       if (check == 1) {
-        fs::dir_create(path = tidywikidatar::tw_get_cache_folder(), recurse = TRUE)
+        fs::dir_create(
+          path = tidywikidatar::tw_get_cache_folder(),
+          recurse = TRUE
+        )
       }
     }
     if (!fs::file_exists(tidywikidatar::tw_get_cache_folder())) {
@@ -38,13 +46,17 @@ tw_create_cache_folder <- function(ask = TRUE) {
 
 #' Set folder for caching data
 #'
-#' Consider using a folder out of your current project directory, e.g. `tw_set_cache_folder("~/R/tw_data/")`: you will be able to use the same cache in different projects, and prevent cached files from being sync-ed if you use services such as Nextcloud or Dropbox.
+#' Consider using a folder out of your current project directory, e.g.
+#' `tw_set_cache_folder("~/R/tw_data/")`: you will be able to use the same cache
+#' in different projects, and prevent cached files from being sync-ed if you use
+#' services such as Nextcloud or Dropbox.
 #'
-#' @param path A path to a location used for caching data. If the folder does not exist, it will be created.
+#' @param path A path to a location used for caching data. If the folder does
+#'   not exist, it will be created.
 #'
-#' @return The path to the caching folder, if previously set; the same path as given to the function; or the default, `tw_data` is none is given.
+#' @return The path to the caching folder, if previously set; the same path as
+#'   given to the function; or the default, `tw_data` is none is given.
 #' @export
-
 #' @examples
 #' \donttest{
 #' if (interactive()) {
@@ -70,14 +82,17 @@ tw_set_cache_folder <- function(path = NULL) {
 tw_get_cache_folder <- tw_set_cache_folder
 
 
-
 #' Set database connection settings for the session
 #'
 #'
 #' @param db_settings A list of database connection settings (see example)
-#' @param driver A database driver. Common database drivers include `MySQL`, `PostgreSQL`, and `MariaDB`. See `unique(odbc::odbcListDrivers()[[1]])` for a list of locally available drivers.
-#' @param host Host address, e.g. "localhost". Different drivers use server or host parameter, only one of them is likely needed.
-#' @param server Server address, e.g. "localhost". Different drivers use server or host parameter, only one of them is likely needed.
+#' @param driver A database driver. Common database drivers include `MySQL`,
+#'   `PostgreSQL`, and `MariaDB`. See `unique(odbc::odbcListDrivers()[[1]])` for
+#'   a list of locally available drivers.
+#' @param host Host address, e.g. "localhost". Different drivers use server or
+#'   host parameter, only one of them is likely needed.
+#' @param server Server address, e.g. "localhost". Different drivers use server
+#'   or host parameter, only one of them is likely needed.
 #' @param port Port to use to connect to the database.
 #' @param database Database name.
 #' @param user Database user name.
@@ -124,22 +139,38 @@ tw_get_cache_folder <- tw_set_cache_folder
 #'   )
 #' }
 #' }
-tw_set_cache_db <- function(db_settings = NULL,
-                            driver = NULL,
-                            host = NULL,
-                            server = NULL,
-                            port = NULL,
-                            database = NULL,
-                            user = NULL,
-                            pwd = NULL) {
-  if (is.null(db_settings) == TRUE) {
-    if (is.null(driver) == FALSE) Sys.setenv(tw_db_driver = driver)
-    if (is.null(host) == FALSE) Sys.setenv(tw_db_host = host)
-    if (is.null(server) == FALSE) Sys.setenv(tw_db_host = server)
-    if (is.null(port) == FALSE) Sys.setenv(tw_db_port = port)
-    if (is.null(database) == FALSE) Sys.setenv(tw_db_database = database)
-    if (is.null(user) == FALSE) Sys.setenv(tw_db_user = user)
-    if (is.null(pwd) == FALSE) Sys.setenv(tw_db_pwd = pwd)
+tw_set_cache_db <- function(
+  db_settings = NULL,
+  driver = NULL,
+  host = NULL,
+  server = NULL,
+  port = NULL,
+  database = NULL,
+  user = NULL,
+  pwd = NULL
+) {
+  if (is.null(db_settings)) {
+    if (is.null(driver) == FALSE) {
+      Sys.setenv(tw_db_driver = driver)
+    }
+    if (is.null(host) == FALSE) {
+      Sys.setenv(tw_db_host = host)
+    }
+    if (is.null(server) == FALSE) {
+      Sys.setenv(tw_db_host = server)
+    }
+    if (is.null(port) == FALSE) {
+      Sys.setenv(tw_db_port = port)
+    }
+    if (is.null(database) == FALSE) {
+      Sys.setenv(tw_db_database = database)
+    }
+    if (is.null(user) == FALSE) {
+      Sys.setenv(tw_db_user = user)
+    }
+    if (is.null(pwd) == FALSE) {
+      Sys.setenv(tw_db_pwd = pwd)
+    }
     return(invisible(
       list(
         driver = driver,
@@ -152,22 +183,37 @@ tw_set_cache_db <- function(db_settings = NULL,
       )
     ))
   } else {
-    if (!is.null(db_settings$driver)) Sys.setenv(tw_db_driver = db_settings$driver)
-    if (!is.null(db_settings$host)) Sys.setenv(tw_db_host = db_settings$host)
-    if (!is.null(db_settings$server)) Sys.setenv(tw_db_server = db_settings$server)
-    if (!is.null(db_settings$port)) Sys.setenv(tw_db_port = db_settings$port)
-    if (!is.null(db_settings$database)) Sys.setenv(tw_db_database = db_settings$database)
-    if (!is.null(db_settings$user)) Sys.setenv(tw_db_user = db_settings$user)
-    if (!is.null(db_settings$pwd)) Sys.setenv(tw_db_pwd = db_settings$pwd)
+    if (!is.null(db_settings$driver)) {
+      Sys.setenv(tw_db_driver = db_settings$driver)
+    }
+    if (!is.null(db_settings$host)) {
+      Sys.setenv(tw_db_host = db_settings$host)
+    }
+    if (!is.null(db_settings$server)) {
+      Sys.setenv(tw_db_server = db_settings$server)
+    }
+    if (!is.null(db_settings$port)) {
+      Sys.setenv(tw_db_port = db_settings$port)
+    }
+    if (!is.null(db_settings$database)) {
+      Sys.setenv(tw_db_database = db_settings$database)
+    }
+    if (!is.null(db_settings$user)) {
+      Sys.setenv(tw_db_user = db_settings$user)
+    }
+    if (!is.null(db_settings$pwd)) {
+      Sys.setenv(tw_db_pwd = db_settings$pwd)
+    }
     return(invisible(db_settings))
   }
 }
 
 #' Get database connection settings from the environment
 #'
-#' Typically set with `tw_set_cache_db()`
+#' Typically set with [tw_set_cache_db()].
 #'
-#' @return A list with all database parameters as stored in environment variables.
+#' @return A list with all database parameters as stored in environment
+#'   variables.
 #' @export
 #'
 #' @examples
@@ -175,20 +221,21 @@ tw_set_cache_db <- function(db_settings = NULL,
 #' tw_get_cache_db()
 tw_get_cache_db <- function() {
   list(
-    driver   = Sys.getenv("tw_db_driver"),
-    host     = Sys.getenv("tw_db_host"),
-    server   = Sys.getenv("tw_db_server"),
-    port     = Sys.getenv("tw_db_port"),
+    driver = Sys.getenv("tw_db_driver"),
+    host = Sys.getenv("tw_db_host"),
+    server = Sys.getenv("tw_db_server"),
+    port = Sys.getenv("tw_db_port"),
     database = Sys.getenv("tw_db_database"),
-    user     = Sys.getenv("tw_db_user"),
-    pwd      = Sys.getenv("tw_db_pwd")
+    user = Sys.getenv("tw_db_user"),
+    pwd = Sys.getenv("tw_db_pwd")
   )
 }
 
 
 #' Enable caching for the current session
 #'
-#' @param SQLite Logical, defaults to TRUE. Set to FALSE to use custom database options. See `tw_set_cache_db()` for details.
+#' @param SQLite Logical, defaults to `TRUE`. Set to `FALSE` to use custom
+#'   database options. See [tw_set_cache_db()] for details.
 #'
 #' @return Nothing, used for its side effects.
 #' @export
@@ -223,11 +270,11 @@ tw_disable_cache <- function() {
 #'
 #' Mostly used internally in functions, exported for reference.
 #'
-#' @param cache Defaults to NULL. If NULL, checks current cache settings. If given, returns given value, ignoring cache.
+#' @param cache Defaults to `NULL`. If `NULL`, checks current cache settings. If
+#'   given, returns given value, ignoring cache.
 #'
-#' @return Either TRUE or FALSE, depending on current cache settings.
+#' @return Either `TRUE` or `FALSE`, depending on current cache settings.
 #' @export
-
 #' @examples
 #' \donttest{
 #' if (interactive()) {
@@ -244,7 +291,8 @@ tw_check_cache <- function(cache = NULL) {
 
 #' Checks if cache folder exists, if not returns an informative message
 #'
-#' @return If the cache folder exists, returns TRUE. Otherwise throws an error.
+#' @return If the cache folder exists, returns `TRUE`. Otherwise throws an
+#'   error.
 #' @export
 #'
 #' @examples
@@ -277,10 +325,18 @@ tw_check_cache_folder <- function() {
 
 #' Ensure that connection to cache is disconnected consistently
 #'
-#' @param cache Defaults to NULL. If given, it should be given either TRUE or FALSE. Typically set with `tw_enable_cache()` or `tw_disable_cache()`.
-#' @param cache_connection Defaults to NULL. If NULL, and caching is enabled, `tidywikidatar` will use a local sqlite database. A custom connection to other databases can be given (see vignette `caching` for details).
-#' @param disconnect_db Defaults to TRUE. If FALSE, leaves the connection to cache open.
-#' @param language Defaults to language set with `tw_set_language()`; if not set, "en". Use "all_available" to keep all languages. For available language values, see https://www.wikidata.org/wiki/Help:Wikimedia_language_codes/lists/all
+#' @param cache Defaults to NULL. If given, it should be given either `TRUE` or
+#'   FALSE. Typically set with [tw_enable_cache()] or [tw_disable_cache()].
+#' @param cache_connection Defaults to `NULL`. If `NULL`, and caching is enabled,
+#'   `tidywikidatar` will use a local sqlite database. A custom connection to
+#'   other databases can be given (see vignette `caching` for details).
+#' @param disconnect_db Defaults to `TRUE`. If `FALSE`, leaves the connection to
+#'   cache open.
+#' @param language Defaults to language set with [tw_set_language()]; if not
+#'   set, "en". Use "all_available" to keep all languages. For available
+#'   language values, see the
+#'   \href{https://www.wikidata.org/wiki/Help:Wikimedia_language_codes/lists/all}{relevant
+#'   Wikimedia page}.
 #'
 #' @return Nothing, used for its side effects.
 #' @export
@@ -293,10 +349,12 @@ tw_check_cache_folder <- function() {
 #'   )
 #'   tw_disconnect_from_cache()
 #' }
-tw_disconnect_from_cache <- function(cache = NULL,
-                                     cache_connection = NULL,
-                                     disconnect_db = TRUE,
-                                     language = tidywikidatar::tw_get_language()) {
+tw_disconnect_from_cache <- function(
+  cache = NULL,
+  cache_connection = NULL,
+  disconnect_db = TRUE,
+  language = tidywikidatar::tw_get_language()
+) {
   if (isFALSE(disconnect_db)) {
     return(invisible(NULL))
   }
