@@ -2,10 +2,12 @@
 #'
 #' This function is mostly used internally and for testing.
 #'
-#' @param w An object of class Wikidata created with `WikidataR`, typically created with `WikidataR::get_item(id = id)`
+#' @param w An object of class Wikidata created with `WikidataR`, typically
+#'   created with `WikidataR::get_item(id = id)`
 #' @inheritParams tw_get
 #'
-#' @return A data frame (a tibble) with four columns, such as the one created by `tw_get`.
+#' @return A data frame (a tibble) with four columns, such as the one created by
+#'   [tw_get()].
 #'
 #' @examples
 #' item <- tryCatch(WikidataR::get_item(id = "Q180099"),
@@ -15,8 +17,7 @@
 #' )
 #'
 #' tidywikidatar:::tw_extract_single(w = item)
-tw_extract_single <- function(w,
-                              language = tidywikidatar::tw_get_language()) {
+tw_extract_single <- function(w, language = tidywikidatar::tw_get_language()) {
   id <- w %>%
     purrr::pluck(1, "id")
 
@@ -25,9 +26,9 @@ tw_extract_single <- function(w,
 
   if (length(labels) == 0) {
     labels_df <- tibble::tibble(
-      property = as.character(NA),
-      value = as.character(NA),
-      rank = as.character(NA)
+      property = NA_character_,
+      value = NA_character_,
+      rank = NA_character_
     ) %>%
       dplyr::slice(0)
   } else {
@@ -43,7 +44,6 @@ tw_extract_single <- function(w,
     )
   }
 
-
   if (language == "all_available") {
     # do nothing
   } else {
@@ -55,11 +55,11 @@ tw_extract_single <- function(w,
 
   if (length(aliases) == 0) {
     aliases_df <- tibble::tibble(
-      property = as.character(NA),
-      values = as.character(NA),
-      rank = as.character(NA)
+      property = NA_character_,
+      values = NA_character_,
+      rank = NA_character_
     ) %>%
-      tidyr::drop_na()
+      dplyr::slice(0)
   } else {
     aliases_df <- purrr::map_dfr(
       .x = aliases,
@@ -67,7 +67,7 @@ tw_extract_single <- function(w,
         tibble::tibble(
           property = paste0("alias_", current_alias_l$language),
           value = current_alias_l$value,
-          rank = as.character(NA)
+          rank = NA_character_
         )
       }
     )
@@ -85,11 +85,11 @@ tw_extract_single <- function(w,
 
   if (length(descriptions) == 0) {
     descriptions_df <- tibble::tibble(
-      property = as.character(NA),
-      values = as.character(NA),
-      rank = as.character(NA)
+      property = NA_character_,
+      values = NA_character_,
+      rank = NA_character_
     ) %>%
-      tidyr::drop_na()
+      dplyr::slice(0)
   } else {
     descriptions_df <- purrr::map_dfr(
       .x = descriptions,
@@ -106,7 +106,9 @@ tw_extract_single <- function(w,
       # do nothing
     } else {
       descriptions_df <- descriptions_df %>%
-        dplyr::filter(.data$property == stringr::str_c("description_", language))
+        dplyr::filter(
+          .data$property == stringr::str_c("description_", language)
+        )
     }
   }
 
@@ -120,7 +122,9 @@ tw_extract_single <- function(w,
 
       rank <- current_claim_l$rank
 
-      value_pre <- claims[[unique(property)]][["mainsnak"]][["datavalue"]][["value"]]
+      value_pre <- claims[[unique(property)]][["mainsnak"]][["datavalue"]][[
+        "value"
+      ]]
 
       if (is.null(value_pre)) {
         value <- as.character("NA")
@@ -132,7 +136,11 @@ tw_extract_single <- function(w,
         } else if (is.element("amount", names(value_pre))) {
           value <- value_pre$amount
         } else if (is.element("latitude", names(value_pre))) {
-          value <- stringr::str_c(value_pre$latitude, value_pre$longitude, sep = ",")
+          value <- stringr::str_c(
+            value_pre$latitude,
+            value_pre$longitude,
+            sep = ","
+          )
         } else if (is.element("id", names(value_pre))) {
           value <- value_pre$id
         } else if (is.na(value_pre[[1]]) == FALSE) {
@@ -154,7 +162,6 @@ tw_extract_single <- function(w,
     }
   )
 
-
   sitelinks <- w %>%
     purrr::pluck(1, "sitelinks")
 
@@ -164,7 +171,7 @@ tw_extract_single <- function(w,
       tibble::tibble(
         property = paste0("sitelink_", current_sitelink_l$site),
         value = current_sitelink_l$title,
-        rank = as.character(NA)
+        rank = NA_character_
       )
     }
   )
@@ -173,19 +180,27 @@ tw_extract_single <- function(w,
     # do nothing
   } else {
     sitelinks_df <- sitelinks_df %>%
-      dplyr::filter((.data$property == stringr::str_c(
-        "sitelink_",
-        language,
-        "wiki"
-      )) | (.data$property == stringr::str_c(
-        "sitelink_",
-        language,
-        "wikiquote"
-      )) | (.data$property == stringr::str_c(
-        "sitelink_",
-        language,
-        "wikisource"
-      )) | (.data$property == "sitelink_commonswiki"))
+      dplyr::filter(
+        (.data$property ==
+          stringr::str_c(
+            "sitelink_",
+            language,
+            "wiki"
+          )) |
+          (.data$property ==
+            stringr::str_c(
+              "sitelink_",
+              language,
+              "wikiquote"
+            )) |
+          (.data$property ==
+            stringr::str_c(
+              "sitelink_",
+              language,
+              "wikisource"
+            )) |
+          (.data$property == "sitelink_commonswiki")
+      )
   }
 
   everything_df <- dplyr::bind_rows(
@@ -206,32 +221,31 @@ tw_extract_single <- function(w,
 }
 
 
-
-
-
 #' Extract qualifiers from an object of class Wikidata created with `WikidataR`
 #'
 #' This function is mostly used internally and for testing.
 #'
-#' @param id A character vector of length 1, must start with Q, e.g. "Q254" for Wolfgang Amadeus Mozart.
-#' @param p A character vector of length 1, a property. Must always start with the capital letter "P", e.g. "P31" for "instance of".
-#' @param w An object of class Wikidata created with `WikidataR`, typically created with `WikidataR::get_item(id = id)`
+#' @param id A character vector of length 1, must start with Q, e.g. "Q254" for
+#'   Wolfgang Amadeus Mozart.
+#' @param p A character vector of length 1, a property. Must always start with
+#'   the capital letter "P", e.g. "P31" for "instance of".
+#' @param w An object of class Wikidata created with `WikidataR`, typically
+#'   created with `WikidataR::get_item(id = id)`
 #'
-#' @return A data frame (a tibble) with eight columns: `id` for the input id, `property`,  `qualifier_id`, `qualifier_property`, `qualifier_value`, `rank`, `qualifier_value_type`, and `set` (to distinguish sets of data when a property is present more than once)
+#' @return A data frame (a tibble) with eight columns: `id` for the input id,
+#'   `property`,  `qualifier_id`, `qualifier_property`, `qualifier_value`,
+#'   `rank`, `qualifier_value_type`, and `set` (to distinguish sets of data when
+#'   a property is present more than once)
 #' @export
 #'
 #' @examples
 #' w <- WikidataR::get_item(id = "Q180099")
 #' tw_extract_qualifier(id = "Q180099", p = "P26", w = w)
-tw_extract_qualifier <- function(id,
-                                 p,
-                                 w = NULL) {
+tw_extract_qualifier <- function(id, p, w = NULL) {
   if (is.null(w)) {
-    w <- tryCatch(WikidataR::get_item(id = id),
-      error = function(e) {
-        as.character(e[[1]])
-      }
-    )
+    w <- tryCatch(WikidataR::get_item(id = id), error = function(e) {
+      as.character(e[[1]])
+    })
 
     if (is.character(w)) {
       cli::cli_alert_danger(w)
@@ -275,7 +289,6 @@ tw_extract_qualifier <- function(id,
         dplyr::slice(i) %>%
         dplyr::pull("qualifiers")
 
-
       purrr::map_dfr(
         .x = qualifiers_set,
         .f = function(x) {
@@ -285,24 +298,26 @@ tw_extract_qualifier <- function(id,
 
           value_df <- current_qualifier[["datavalue"]][["value"]] %>%
             tibble::as_tibble()
-          if (is.element("id", names(value_df)) == TRUE) {
+          if (is.element("id", names(value_df))) {
             value <- value_df %>%
               dplyr::pull("id")
-          } else if (is.element("value", names(value_df)) == TRUE) {
+          } else if (is.element("value", names(value_df))) {
             value <- value_df %>%
               dplyr::pull("value")
-          } else if (is.element("amount", names(value_df)) == TRUE) {
+          } else if (is.element("amount", names(value_df))) {
             value <- value_df %>%
               dplyr::pull("amount")
-          } else if (is.element("time", names(value_df)) == TRUE) {
+          } else if (is.element("time", names(value_df))) {
             value <- value_df %>%
               dplyr::pull("time")
           } else {
-            return(tidywikidatar::tw_empty_qualifiers %>%
-              dplyr::select(
-                -"id",
-                -"property"
-              ))
+            return(
+              tidywikidatar::tw_empty_qualifiers %>%
+                dplyr::select(
+                  -"id",
+                  -"property"
+                )
+            )
           }
 
           tibble::tibble(
