@@ -2,13 +2,19 @@
 #'
 #' This function does not cache results.
 #'
-#' @param p A character vector, a property. Must always start with the capital letter "P", e.g. "P31" for "instance of".
+#' @param p A character vector, a property. Must always start with the capital
+#'   letter "P", e.g. "P31" for "instance of".
 #' @param wait Defaults to 0.1. Used only in method is set to "JSON".
-#' @param method Defaults to "SPARQL". The only accepted alternative value is "JSON", to use instead json-based API.
-#' @param limit Defaults to `Inf`. Set to smaller values for testing and cache locally when possible to reduce load on servers.
+#' @param method Defaults to "SPARQL". The only accepted alternative value is
+#'   "JSON", to use instead json-based API.
+#' @param limit Defaults to `Inf`. Set to smaller values for testing and cache
+#'   locally when possible to reduce load on servers.
 #' @inheritParams tw_query
 #'
-#' @return A data frame with three columns is method is set to "SPARQL", or as many columns as fields if more are given and `return_as_tw_search` is set to FALSE. A single column with Wikidata identifier if method is set to "JSON".
+#' @return A data frame with three columns is method is set to "SPARQL", or as
+#'   many columns as fields if more are given and `return_as_tw_search` is set
+#'   to `FALSE`. A single column with Wikidata identifier if method is set to
+#'   "JSON".
 #' @export
 #'
 #' @examples
@@ -16,13 +22,16 @@
 #'   # get all Wikidata items with an ICAO airport code ("P239")
 #'   tw_get_all_with_p(p = "P239", limit = 10)
 #' }
-tw_get_all_with_p <- function(p,
-                              fields = c("item", "itemLabel", "itemDescription"),
-                              language = tidywikidatar::tw_get_language(),
-                              method = "SPARQL",
-                              wait = 0.1,
-                              limit = Inf,
-                              return_as_tw_search = TRUE) {
+tw_get_all_with_p <- function(
+  p,
+  fields = c("item", "itemLabel", "itemDescription"),
+  language = tidywikidatar::tw_get_language(),
+  method = "SPARQL",
+  wait = 0.1,
+  limit = Inf,
+  return_as_tw_search = TRUE,
+  user_agent = tidywikidatar::tw_get_user_agent()
+) {
   p <- stringr::str_to_upper(string = p)
 
   if (stringr::str_starts(string = p, pattern = "P", negate = TRUE)) {
@@ -30,8 +39,10 @@ tw_get_all_with_p <- function(p,
     if (method == "SPARQL") {
       return(tidywikidatar::tw_empty_search)
     } else if (method == "API") {
-      return(tibble::tibble(id = as.character(NA)) %>%
-        dplyr::slice(0))
+      return(
+        tibble::tibble(id = NA_character_) %>%
+          dplyr::slice(0)
+      )
     }
   }
 
@@ -57,18 +68,24 @@ tw_get_all_with_p <- function(p,
       )
     }
 
+    req <- httr2::request("https://query.wikidata.org/sparql") %>%
+      httr2::req_headers(Accept = "text/csv") %>%
+      httr2::req_user_agent(user_agent) %>%
+      httr2::req_url_query(query = sparql_t) %>%
+      httr2::req_retry(max_tries = 5, backoff = ~2)
 
-    response <- WikidataQueryServiceR::query_wikidata(
-      sparql_query = sparql_t,
-      format = "simple"
-    )
+    resp <- httr2::req_perform(req)
 
-    if (length(fields) == 3 & return_as_tw_search == TRUE) {
+    response <- read.csv(
+      text = httr2::resp_body_string(resp),
+      stringsAsFactors = FALSE
+    ) %>%
+      tibble::as_tibble()
+
+    if (length(fields) == 3 & return_as_tw_search) {
       all_items_df <- response %>%
         dplyr::transmute(
-          id = stringr::str_extract(.data$item,
-            pattern = "Q[[:digit:]]+$"
-          ),
+          id = stringr::str_extract(.data$item, pattern = "Q[[:digit:]]+$"),
           label = .data$itemLabel,
           description = .data$itemDescription
         )
@@ -92,7 +109,9 @@ tw_get_all_with_p <- function(p,
 
     all_jsons[[page_number]] <- base_json
 
-    while (is.null(continue_check) == FALSE & page_number < max(2, (limit / 500))) {
+    while (
+      is.null(continue_check) == FALSE & page_number < max(2, (limit / 500))
+    ) {
       Sys.sleep(wait)
       cli::cli_alert_info("Page {page_number} extracted")
       page_number <- page_number + 1
@@ -111,7 +130,9 @@ tw_get_all_with_p <- function(p,
 
     all_pages <- purrr::map(
       .x = all_jsons,
-      .f = purrr::pluck, "query", "backlinks"
+      .f = purrr::pluck,
+      "query",
+      "backlinks"
     ) %>%
       purrr::flatten()
 
