@@ -2,13 +2,14 @@
 #'
 #' Mostly used internally
 #'
-#' @param url A character vector with the full URL to one or more Wikipedia pages. If given, title and language can be left empty.
-#' @param title Title of a Wikipedia page or final parts of its url. If given, url can be left empty, but language must be provided.
-#' @param language Two-letter language code used to define the Wikipedia version to use. Defaults to language set with `tw_set_language()`; if not set, "en". If url given, this can be left empty.
-#' @param action Defaults to "query". Usually either "query" or "parse". In principle, any valid action value, see: \url{https://www.mediawiki.org/w/api.php}
+#' @param action Defaults to "query". Usually either "query" or "parse". In
+#'   principle, any valid action value, see:
+#'   \url{https://www.mediawiki.org/w/api.php}
 #' @param type Defaults to "page". Either "page" or "category".
+#' @inheritParams tw_get_wikipedia_page_qid
+#' @inheritParams tw_get
 #'
-#' @return A character vector of base urls to be used with the MediaWiki API
+#' @return A character vector of base urls to be used with the MediaWiki API.
 #' @export
 #'
 #' @examples
@@ -18,11 +19,13 @@
 #'   type = "category",
 #'   language = "en"
 #' )
-tw_get_wikipedia_base_api_url <- function(url = NULL,
-                                          title = NULL,
-                                          language = tidywikidatar::tw_get_language(),
-                                          action = "query",
-                                          type = "page") {
+tw_get_wikipedia_base_api_url <- function(
+  url = NULL,
+  title = NULL,
+  language = tidywikidatar::tw_get_language(),
+  action = "query",
+  type = "page"
+) {
   if (is.null(url)) {
     if (is.null(title)) {
       cli::cli_abort("Either {.arg url} or {.arg title} must be provided.")
@@ -34,7 +37,10 @@ tw_get_wikipedia_base_api_url <- function(url = NULL,
     check_url_lv <- stringr::str_starts(string = url, pattern = "http")
     if (sum(is.na(check_url_lv)) > 0) {
       url <- url[is.na(check_url_lv) == FALSE]
-      cli::cli_warn(c("One or more of the given URLs is actually NA.", i = "Only valid URLs will be processed."))
+      cli::cli_warn(c(
+        "One or more of the given URLs is actually NA.",
+        i = "Only valid URLs will be processed."
+      ))
     }
     check_url_lv <- stringr::str_starts(string = url, pattern = "http")
     if (sum(check_url_lv) != length(check_url_lv)) {
@@ -49,7 +55,7 @@ tw_get_wikipedia_base_api_url <- function(url = NULL,
     )
   }
 
-  if (is.null(language) == TRUE) {
+  if (is.null(language)) {
     language <- stringr::str_extract(
       string = url,
       pattern = "(?<=https://)[[a-z]][[a-z]](?=.wikipedia.org/)"
@@ -93,17 +99,17 @@ tw_get_wikipedia_base_api_url <- function(url = NULL,
 
 #' Gets the Wikidata Q identifier of one or more Wikipedia pages
 #'
-#' @param url A character vector with the full URL to one or more Wikipedia pages. If given, title and language can be left empty.
-#' @param title Title of a Wikipedia page or final parts of its url. If given, url can be left empty, but language must be provided.
-#' @param language Two-letter language code used to define the Wikipedia version to use. Defaults to language set with `tw_set_language()`; if not set, "en". If url given, this can be left empty.
-#' @param cache Defaults to NULL. If given, it should be given either TRUE or FALSE. Typically set with `tw_enable_cache()` or `tw_disable_cache()`.
-#' @param overwrite_cache Logical, defaults to FALSE. If TRUE, it overwrites the table in the local sqlite database. Useful if the original Wikidata object has been updated.
-#' @param cache_connection Defaults to NULL. If NULL, and caching is enabled, `tidywikidatar` will use a local sqlite database. A custom connection to other databases can be given (see vignette `caching` for details).
-#' @param disconnect_db Defaults to TRUE. If FALSE, leaves the connection to cache open.
-#' @param wait In seconds, defaults to 1 due to time-outs with frequent queries. Time to wait between queries to the APIs. If data are cached locally, wait time is not applied. If you are running many queries systematically you may want to add some waiting time between queries.
-#' @param attempts Defaults to 10. Number of times it re-attempts to reach the API before failing.
+#' @param url A character vector with the full URL to one or more Wikipedia
+#'   pages. If given, title and language can be left empty.
+#' @param title Title of a Wikipedia page or final parts of its url. If given,
+#'   url can be left empty, but language must be provided.
+#' @param attempts Defaults to 10. Number of times it re-attempts to reach the
+#'   API before failing.
+#' @inheritParams tw_get
 #'
-#' @return A a data frame with six columns, including `qid` with Wikidata identifiers, and a logical `disambiguation` to flag when disambiguation pages are returned.
+#' @return A a data frame with six columns, including `qid` with Wikidata
+#'   identifiers, and a logical `disambiguation` to flag when disambiguation
+#'   pages are returned.
 #' @export
 #'
 #' @examples
@@ -113,34 +119,39 @@ tw_get_wikipedia_base_api_url <- function(url = NULL,
 #'   # check when Wikipedia returns disambiguation page
 #'   tw_get_wikipedia_page_qid(title = c("Rome", "London", "New York", "Vienna"))
 #' }
-tw_get_wikipedia_page_qid <- function(url = NULL,
-                                      title = NULL,
-                                      language = tidywikidatar::tw_get_language(),
-                                      cache = NULL,
-                                      overwrite_cache = FALSE,
-                                      cache_connection = NULL,
-                                      disconnect_db = TRUE,
-                                      wait = 1,
-                                      attempts = 10) {
+tw_get_wikipedia_page_qid <- function(
+  url = NULL,
+  title = NULL,
+  language = tidywikidatar::tw_get_language(),
+  cache = NULL,
+  overwrite_cache = FALSE,
+  cache_connection = NULL,
+  disconnect_db = TRUE,
+  wait = 1,
+  attempts = 10
+) {
   if (is.null(url) == FALSE) {
     if (is.null(title)) {
       title <- dplyr::case_when(
-        stringr::str_starts(string = url, pattern = "http") ~ stringr::str_extract(
-          string = url,
-          pattern = "(?<=https://[[a-z]][[a-z]].wikipedia.org/wiki/).*"
-        ),
-        stringr::str_starts(string = url,
-                            pattern = stringr::fixed("/wiki/")) ~ stringr::str_remove(
-                              string = url,
-                              pattern = stringr::fixed("/wiki/")
-                            ),
+        stringr::str_starts(string = url, pattern = "http") ~
+          stringr::str_extract(
+            string = url,
+            pattern = "(?<=https://[[a-z]][[a-z]].wikipedia.org/wiki/).*"
+          ),
+        stringr::str_starts(string = url, pattern = stringr::fixed("/wiki/")) ~
+          stringr::str_remove(
+            string = url,
+            pattern = stringr::fixed("/wiki/")
+          ),
         .default = ""
       )
     } else {
       cli::cli_abort("Either url or title must be provided, not both.")
     }
 
-    if (sum(stringr::str_starts(string = url, pattern = "http"))==length(url)) {
+    if (
+      sum(stringr::str_starts(string = url, pattern = "http")) == length(url)
+    ) {
       language <- stringr::str_extract(
         string = url,
         pattern = "(?<=https://)[[a-z]][[a-z]](?=.wikipedia.org/)"
@@ -153,7 +164,9 @@ tw_get_wikipedia_page_qid <- function(url = NULL,
   if (length(unique_language) == 0) {
     return(tidywikidatar::tw_empty_wikipedia_page)
   } else if (length(unique_language) > 1) {
-    cli::cli_abort("{.fn tw_get_wikipedia_page_qid} currently accepts only inputs with one language at a time.")
+    cli::cli_abort(
+      "{.fn tw_get_wikipedia_page_qid} currently accepts only inputs with one language at a time."
+    )
   }
 
   unique_title <- unique(title)
@@ -187,7 +200,7 @@ tw_get_wikipedia_page_qid <- function(url = NULL,
       )
     )
   } else if (length(unique_title) > 1) {
-    if (overwrite_cache == TRUE | tw_check_cache(cache) == FALSE) {
+    if (overwrite_cache | tw_check_cache(cache) == FALSE) {
       pb <- progress::progress_bar$new(total = length(unique_title))
 
       df <- purrr::map_dfr(
@@ -223,7 +236,7 @@ tw_get_wikipedia_page_qid <- function(url = NULL,
       )
     }
 
-    if (overwrite_cache == FALSE & tw_check_cache(cache) == TRUE) {
+    if (overwrite_cache == FALSE & tw_check_cache(cache)) {
       titles_in_cache_df <- tw_get_cached_wikipedia_page_qid(
         title = unique_title,
         language = unique_language,
@@ -231,7 +244,9 @@ tw_get_wikipedia_page_qid <- function(url = NULL,
         disconnect_db = FALSE
       )
 
-      titles_not_in_cache <- unique_title[!is.element(unique_title, titles_in_cache_df$title_url)]
+      titles_not_in_cache <- unique_title[
+        !is.element(unique_title, titles_in_cache_df$title_url)
+      ]
 
       if (length(titles_not_in_cache) == 0) {
         tw_disconnect_from_cache(
@@ -291,37 +306,37 @@ tw_get_wikipedia_page_qid <- function(url = NULL,
 
 #' Gets the Wikidata id of a Wikipedia page
 #'
-#' @param title Title of a Wikipedia page or final parts of its url. If given, url can be left empty, but language must be provided.
-#' @param url Full URL to a Wikipedia page. If given, title and language can be left empty.
-#' @param language Two-letter language code used to define the Wikipedia version to use. Defaults to language set with `tw_set_language()`; if not set, "en". If url given, this can be left empty.
-#' @param cache Defaults to NULL. If given, it should be given either TRUE or FALSE. Typically set with `tw_enable_cache()` or `tw_disable_cache()`.
-#' @param overwrite_cache Logical, defaults to FALSE. If TRUE, it overwrites the table in the local sqlite database. Useful if the original Wikidata object has been updated.
-#' @param cache_connection Defaults to NULL. If NULL, and caching is enabled, `tidywikidatar` will use a local sqlite database. A custom connection to other databases can be given (see vignette `caching` for details).
-#' @param disconnect_db Defaults to TRUE. If FALSE, leaves the connection to cache open.
-#' @param wait In seconds, defaults to 1 due to time-outs with frequent queries. Time to wait between queries to the APIs. If data are cached locally, wait time is not applied. If you are running many queries systematically you may want to add some waiting time between queries.
-#' @param attempts Defaults to 10. Number of times it re-attempts to reach the API before failing.
+#' @inheritParams tw_get
+#' @inheritParams tw_get_wikipedia_page_qid
 #'
-#' @return A data frame (a tibble) with eight columns: `title`, `wikipedia_title`, `wikipedia_id`, `qid`, `description`, `disambiguation`, and `language`.
+#' @return A data frame (a tibble) with eight columns: `title`,
+#'   `wikipedia_title`, `wikipedia_id`, `qid`, `description`, `disambiguation`,
+#'   and `language`.
 #'
 #' @examples
 #' if (interactive()) {
 #'   tw_get_wikipedia_page_qid_single(title = "Margaret Mead", language = "en")
 #' }
-tw_get_wikipedia_page_qid_single <- function(title = NULL,
-                                             url = NULL,
-                                             language = tidywikidatar::tw_get_language(),
-                                             cache = NULL,
-                                             overwrite_cache = FALSE,
-                                             cache_connection = NULL,
-                                             disconnect_db = TRUE,
-                                             wait = 1,
-                                             attempts = 10) {
+tw_get_wikipedia_page_qid_single <- function(
+  title = NULL,
+  url = NULL,
+  language = tidywikidatar::tw_get_language(),
+  cache = NULL,
+  overwrite_cache = FALSE,
+  cache_connection = NULL,
+  disconnect_db = TRUE,
+  wait = 1,
+  attempts = 10
+) {
   if (!is.null(url) && !is.function(url)) {
     if (is.null(title) & is.function(title) == FALSE) {
-      if (stringr::str_starts(string = url,
-                              pattern = stringr::fixed("/wiki/"))) {
-        title <- stringr::str_remove(string = url,
-                                     pattern = stringr::fixed("/wiki/"))
+      if (
+        stringr::str_starts(string = url, pattern = stringr::fixed("/wiki/"))
+      ) {
+        title <- stringr::str_remove(
+          string = url,
+          pattern = stringr::fixed("/wiki/")
+        )
       } else {
         title <- stringr::str_extract(
           string = url,
@@ -345,7 +360,7 @@ tw_get_wikipedia_page_qid_single <- function(title = NULL,
     cache = cache
   )
 
-  if (tw_check_cache(cache) == TRUE & overwrite_cache == FALSE) {
+  if (tw_check_cache(cache) & overwrite_cache == FALSE) {
     db_result <- tw_get_cached_wikipedia_page_qid(
       title = title,
       language = language,
@@ -354,8 +369,10 @@ tw_get_wikipedia_page_qid_single <- function(title = NULL,
       disconnect_db = disconnect_db
     )
     if (is.data.frame(db_result) & nrow(db_result) > 0) {
-      return(db_result %>%
-        tibble::as_tibble())
+      return(
+        db_result %>%
+          tibble::as_tibble()
+      )
     }
   }
 
@@ -382,17 +399,15 @@ tw_get_wikipedia_page_qid_single <- function(title = NULL,
     Sys.sleep(time = wait)
   }
 
-
   if (isFALSE(api_result)) {
     cli::cli_abort(c(
-      "Could not reach the API with {attempts} attempts.",
+      x = "Could not reach the API with {attempts} attempts.",
       i = "Consider increasing the waiting time between calls with the {.arg wait} parameter or check your internet connection."
     ))
   } else {
     wikidata_id_l <- api_result
   }
 
-
   wikipedia_id <- wikidata_id_l %>%
     purrr::pluck(
       "query",
@@ -417,7 +432,7 @@ tw_get_wikipedia_page_qid_single <- function(title = NULL,
     )
 
   if (is.null(wikidata_id)) {
-    wikidata_id <- as.character(NA)
+    wikidata_id <- NA_character_
   }
 
   description <- wikidata_id_l %>%
@@ -430,7 +445,7 @@ tw_get_wikipedia_page_qid_single <- function(title = NULL,
     )
 
   if (is.null(description)) {
-    description <- as.character(NA)
+    description <- NA_character_
   }
 
   disambiguation <- is.element(
@@ -454,7 +469,7 @@ tw_get_wikipedia_page_qid_single <- function(title = NULL,
     )
 
   if (is.null(normalised)) {
-    normalised <- as.character(NA)
+    normalised <- NA_character_
   }
 
   redirected <- wikidata_id_l %>%
@@ -466,13 +481,13 @@ tw_get_wikipedia_page_qid_single <- function(title = NULL,
     )
 
   if (is.null(redirected)) {
-    redirected <- as.character(NA)
+    redirected <- NA_character_
   }
 
   wikipedia_title <- dplyr::case_when(
     is.na(redirected) == FALSE ~ redirected,
     is.na(normalised) == FALSE ~ normalised,
-    is.na(wikipedia_id) == TRUE ~ as.character(NA),
+    is.na(wikipedia_id) == TRUE ~ NA_character_,
     TRUE ~ title
   )
 
@@ -486,7 +501,7 @@ tw_get_wikipedia_page_qid_single <- function(title = NULL,
     language = as.character(language)
   )
 
-  if (tw_check_cache(cache) == TRUE) {
+  if (tw_check_cache(cache)) {
     tw_write_qid_of_wikipedia_page_to_cache(
       df = df,
       cache = cache,
@@ -501,16 +516,13 @@ tw_get_wikipedia_page_qid_single <- function(title = NULL,
 }
 
 
-
 #' Gets id of Wikipedia pages from local cache
 #'
 #' Mostly used internally.
 #'
-#' @param title Title of a Wikipedia page or final parts of its url. If given, url can be left empty, but language must be provided.
-#' @param language Defaults to language set with `tw_set_language()`; if not set, "en". Use "all_available" to keep all languages. For available language values, see https://www.wikidata.org/wiki/Help:Wikimedia_language_codes/lists/all
-#' @param cache Defaults to NULL. If given, it should be given either TRUE or FALSE. Typically set with `tw_enable_cache()` or `tw_disable_cache()`.
-#' @param cache_connection Defaults to NULL. If NULL, and caching is enabled, `tidywikidatar` will use a local sqlite database. A custom connection to other databases can be given (see vignette `caching` for details).
-#' @param disconnect_db Defaults to TRUE. If FALSE, leaves the connection open.
+#' @param title Title of a Wikipedia page or final parts of its url. If given,
+#'   url can be left empty, but language must be provided.
+#' @inheritParams tw_get
 #'
 #' @return If data present in cache, returns a data frame with cached data.
 #' @export
@@ -530,11 +542,13 @@ tw_get_wikipedia_page_qid_single <- function(title = NULL,
 #'
 #'   df_from_cache
 #' }
-tw_get_cached_wikipedia_page_qid <- function(title,
-                                             language = tidywikidatar::tw_get_language(),
-                                             cache = NULL,
-                                             cache_connection = NULL,
-                                             disconnect_db = TRUE) {
+tw_get_cached_wikipedia_page_qid <- function(
+  title,
+  language = tidywikidatar::tw_get_language(),
+  cache = NULL,
+  cache_connection = NULL,
+  disconnect_db = TRUE
+) {
   if (isFALSE(tw_check_cache(cache = cache))) {
     return(invisible(NULL))
   }
@@ -553,7 +567,7 @@ tw_get_cached_wikipedia_page_qid <- function(title,
   )
 
   if (pool::dbExistsTable(conn = db, name = table_name) == FALSE) {
-    if (disconnect_db == TRUE) {
+    if (disconnect_db) {
       tw_disconnect_from_cache(
         cache = cache,
         cache_connection = db,
@@ -574,7 +588,7 @@ tw_get_cached_wikipedia_page_qid <- function(title,
     }
   )
   if (isFALSE(db_result)) {
-    if (disconnect_db == TRUE) {
+    if (disconnect_db) {
       tw_disconnect_from_cache(
         cache = cache,
         cache_connection = db,
@@ -589,7 +603,7 @@ tw_get_cached_wikipedia_page_qid <- function(title,
     dplyr::collect() %>%
     dplyr::mutate(disambiguation = as.logical(.data$disambiguation))
 
-  if (disconnect_db == TRUE) {
+  if (disconnect_db) {
     tw_disconnect_from_cache(
       cache = cache,
       cache_connection = db,
@@ -601,19 +615,18 @@ tw_get_cached_wikipedia_page_qid <- function(title,
 }
 
 
-
 #' Write Wikidata identifier (qid) of Wikipedia page to cache
 #'
-#' Mostly used internally by `tidywikidatar`, use with caution to keep caching consistent.
+#' Mostly used internally by `tidywikidatar`, use with caution to keep caching
+#' consistent.
 #'
-#' @param df A data frame typically generated with `tw_get_wikipedia_page_qid()`.
-#' @param language Defaults to language set with `tw_set_language()`; if not set, "en". Use "all_available" to keep all languages. For available language values, see https://www.wikidata.org/wiki/Help:Wikimedia_language_codes/lists/all
-#' @param cache Defaults to NULL. If given, it should be given either TRUE or FALSE. Typically set with `tw_enable_cache()` or `tw_disable_cache()`.
-#' @param overwrite_cache Logical, defaults to FALSE. If TRUE, it overwrites the table in the local sqlite database. Useful if the original Wikidata object has been updated.
-#' @param cache_connection Defaults to NULL. If NULL, and caching is enabled, `tidywikidatar` will use a local sqlite database. A custom connection to other databases can be given (see vignette `caching` for details).
-#' @param disconnect_db Defaults to TRUE. If FALSE, leaves the connection to cache open.
+#' @param df A data frame typically generated with
+#'   [tw_get_wikipedia_page_qid()].
 #'
-#' @return Silently returns the same data frame provided as input. Mostly used internally for its side effects.
+#' @inheritParams tw_get
+#'
+#' @return Silently returns the same data frame provided as input. Mostly used
+#'   internally for its side effects.
 #'
 #' @export
 #'
@@ -631,12 +644,14 @@ tw_get_cached_wikipedia_page_qid <- function(title,
 #'     language = "en"
 #'   )
 #' }
-tw_write_qid_of_wikipedia_page_to_cache <- function(df,
-                                                    language = tidywikidatar::tw_get_language(),
-                                                    cache = NULL,
-                                                    overwrite_cache = FALSE,
-                                                    cache_connection = NULL,
-                                                    disconnect_db = TRUE) {
+tw_write_qid_of_wikipedia_page_to_cache <- function(
+  df,
+  language = tidywikidatar::tw_get_language(),
+  cache = NULL,
+  overwrite_cache = FALSE,
+  cache_connection = NULL,
+  disconnect_db = TRUE
+) {
   if (isFALSE(tw_check_cache(cache = cache))) {
     return(invisible(NULL))
   }
@@ -655,8 +670,9 @@ tw_write_qid_of_wikipedia_page_to_cache <- function(df,
   if (pool::dbExistsTable(conn = db, name = table_name) == FALSE) {
     # do nothing: if table does not exist, previous data cannot be there
   } else {
-    if (overwrite_cache == TRUE) {
-      statement <- glue::glue_sql("DELETE FROM {`table_name`} WHERE title_url = {title_url*}",
+    if (overwrite_cache) {
+      statement <- glue::glue_sql(
+        "DELETE FROM {`table_name`} WHERE title_url = {title_url*}",
         title_url = unique(df$title_url),
         table_name = table_name,
         .con = db
@@ -668,11 +684,7 @@ tw_write_qid_of_wikipedia_page_to_cache <- function(df,
     }
   }
 
-  pool::dbWriteTable(db,
-    name = table_name,
-    value = df,
-    append = TRUE
-  )
+  pool::dbWriteTable(db, name = table_name, value = df, append = TRUE)
 
   tw_disconnect_from_cache(
     cache = cache,
@@ -686,13 +698,11 @@ tw_write_qid_of_wikipedia_page_to_cache <- function(df,
 
 #' Reset Wikipedia page cache
 #'
-#' Removes the table where data typically gathered with `tw_get_wikipedia_page_qid()` from cache
+#' Removes the table where data typically gathered with
+#' [tw_get_wikipedia_page_qid()] from cache.
 #'
-#' @param language Defaults to language set with `tw_set_language()`; if not set, "en". Use "all_available" to keep all languages. For available language values, see https://www.wikidata.org/wiki/Help:Wikimedia_language_codes/lists/all
-#' @param cache Defaults to NULL. If given, it should be given either TRUE or FALSE. Typically set with `tw_enable_cache()` or `tw_disable_cache()`.
-#' @param cache_connection Defaults to NULL. If NULL, and caching is enabled, `tidywikidatar` will use a local sqlite database. A custom connection to other databases can be given (see vignette `caching` for details).
-#' @param disconnect_db Defaults to TRUE. If FALSE, leaves the connection to cache open.
-#' @param ask Logical, defaults to TRUE. If FALSE, and cache folder does not exist, it just creates it without asking (useful for non-interactive sessions).
+#' @inheritParams tw_get
+#' @inheritParams tw_reset_item_cache
 #'
 #' @return Nothing, used for its side effects.
 #' @export
@@ -701,11 +711,13 @@ tw_write_qid_of_wikipedia_page_to_cache <- function(df,
 #' if (interactive()) {
 #'   tw_reset_wikipedia_page_cache()
 #' }
-tw_reset_wikipedia_page_cache <- function(language = tidywikidatar::tw_get_language(),
-                                          cache = NULL,
-                                          cache_connection = NULL,
-                                          disconnect_db = TRUE,
-                                          ask = TRUE) {
+tw_reset_wikipedia_page_cache <- function(
+  language = tidywikidatar::tw_get_language(),
+  cache = NULL,
+  cache_connection = NULL,
+  disconnect_db = TRUE,
+  ask = TRUE
+) {
   db <- tw_connect_to_cache(
     connection = cache_connection,
     language = language,
@@ -717,17 +729,30 @@ tw_reset_wikipedia_page_cache <- function(language = tidywikidatar::tw_get_langu
     language = language
   )
 
-  if (pool::dbExistsTable(conn = db, name = table_name) == FALSE) {
+  if (!pool::dbExistsTable(conn = db, name = table_name)) {
     # do nothing: if table does not exist, nothing to delete
   } else if (isFALSE(ask)) {
     pool::dbRemoveTable(conn = db, name = table_name)
-    cli::cli_alert_info("Wikipedia page cache reset for language {.val {language}} completed.")
-  } else if (utils::menu(c("Yes", "No"), title = paste0("Are you sure you want to remove from cache the qualifiers table for language: ", sQuote(language), "?")) == 1) {
+    cli::cli_alert_info(
+      "Wikipedia page cache reset for language {.val {language}} completed."
+    )
+  } else if (
+    utils::menu(
+      c("Yes", "No"),
+      title = paste0(
+        "Are you sure you want to remove from cache the qualifiers table for language: ",
+        sQuote(language),
+        "?"
+      )
+    ) ==
+      1
+  ) {
     pool::dbRemoveTable(conn = db, name = table_name)
-    cli::cli_alert_info("Wikipedia page cache reset for language {.val {language}} completed.")
+    cli::cli_alert_info(
+      "Wikipedia page cache reset for language {.val {language}} completed."
+    )
   }
 
-
   tw_disconnect_from_cache(
     cache = cache,
     cache_connection = db,
