@@ -1,35 +1,61 @@
-#' Search for Wikidata items or properties and return Wikidata id, label, and description.
+#' Search for Wikidata items or properties and return Wikidata id, label, and
+#' description.
 #'
-#' By defaults, this search returns items. Set `type` to property or use `tw_search_property()` for properties.
+#' By defaults, this search returns items. Set `type` to property or use
+#' [tw_search_property()] for properties.
 #'
 #' @param search A string to be searched in Wikidata
 #' @param type Defaults to "item". Either "item" or "property".
-#' @param language Language to be used for the search. Can be set once per session with `tw_set_language()`. If not set, defaults to "en". For a full list, see https://www.wikidata.org/wiki/Help:Wikimedia_language_codes/lists/all
-#' @param response_language Language to be used for the returned labels and descriptions. Corresponds to the `uselang` parameter of the MediaWiki API: https://www.wikidata.org/w/api.php?action=help&modules=wbsearchentities. Can be set once per session with `tw_set_language()`. If not set, defaults to "en". For a full list, see https://www.wikidata.org/wiki/Help:Wikimedia_language_codes/lists/all
+#' @param language Language to be used for the search. Can be set once per
+#'   session with [tw_set_language()]. If not set, defaults to "en". For a full
+#'   list, see
+#'   \href{https://www.wikidata.org/wiki/Help:Wikimedia_language_codes/lists/all}{the
+#'   dedicated Wikimedia page}.
+#' @param response_language Language to be used for the returned labels and
+#'   descriptions. Corresponds to the `uselang` parameter of the MediaWiki API,
+#'   as described
+#'   \href{https://www.wikidata.org/w/api.php?action=help&modules=wbsearchentities}{in
+#'   the official documentation}. Can be set once per session with
+#'   [tw_set_language()]. If not set, defaults to "en". For a full list, see
+#'   \href{https://www.wikidata.org/wiki/Help:Wikimedia_language_codes/lists/all}{all
+#'   available language codes}.
 #' @param limit Maximum numbers of responses to be given.
-#' @param include_search Logical, defaults to FALSE. If TRUE, the search is returned as an additional column.
-#' @param wait In seconds, defaults to 0. Time to wait between queries to Wikidata. If data are cached locally, wait time is not applied. If you are running many queries systematically you may want to add some waiting time between queries.
-#' @param cache Defaults to NULL. If given, it should be given either TRUE or FALSE. Typically set with `tw_enable_cache()` or `tw_disable_cache()`.
-#' @param overwrite_cache Defaults to FALSE. If TRUE, overwrites cache.
-#' @param cache_connection Defaults to NULL. If NULL, and caching is enabled, `tidywikidatar` will use a local sqlite database. A custom connection to other databases can be given (see vignette `caching` for details).
-#' @param disconnect_db Defaults to TRUE. If FALSE, leaves the connection to cache open.
+#' @param include_search Logical, defaults to `FALSE`. If `TRUE`, the search is
+#'   returned as an additional column.
+#' @param wait In seconds, defaults to 0. Time to wait between queries to
+#'   Wikidata. If data are cached locally, wait time is not applied. If you are
+#'   running many queries systematically you may want to add some waiting time
+#'   between queries.
+#' @param cache Defaults to `NULL`. If given, it should be given either `TRUE`
+#'   or `FALSE.` Typically set with [tw_enable_cache()] or [tw_disable_cache()].
+#' @param overwrite_cache Defaults to `FALSE`. If `TRUE`, overwrites cache.
+#' @param cache_connection Defaults to `NULL`. If `NULL`, and caching is
+#'   enabled, `tidywikidatar` will use a local sqlite database. A custom
+#'   connection to other databases can be given (see vignette `caching` for
+#'   details).
+#' @param disconnect_db Defaults to `TRUE`. If `FALSE`, leaves the connection to
+#'   cache open.
 #'
-#' @return A data frame (a tibble) with three columns (id, label, and description), and as many rows as there are results (by default, limited to 10). Four columns when `include_search` is set to TRUE.
+#' @return A data frame (a tibble) with three columns (`id`, `label`, and
+#'   `description`), and as many rows as there are results (by default, limited
+#'   to 10). Four columns when `include_search` is set to `TRUE`.
 #' @export
 #'
 #' @examples
 #' tw_search(search = c("Margaret Mead", "Ruth Benedict"))
-tw_search <- function(search,
-                      type = "item",
-                      language = tidywikidatar::tw_get_language(),
-                      response_language = tidywikidatar::tw_get_language(),
-                      limit = 10,
-                      include_search = FALSE,
-                      wait = 0,
-                      cache = NULL,
-                      overwrite_cache = FALSE,
-                      cache_connection = NULL,
-                      disconnect_db = TRUE) {
+tw_search <- function(
+  search,
+  type = "item",
+  language = tidywikidatar::tw_get_language(),
+  response_language = tidywikidatar::tw_get_language(),
+  limit = 10,
+  include_search = FALSE,
+  wait = 0,
+  cache = NULL,
+  overwrite_cache = FALSE,
+  cache_connection = NULL,
+  disconnect_db = TRUE
+) {
   rlang::check_required(search)
 
   if (length(search) == 0) {
@@ -70,14 +96,16 @@ tw_search <- function(search,
         by = "search"
       )
 
-    if (include_search == TRUE) {
+    if (include_search) {
       return(search_df)
     } else {
-      return(search_df %>%
-        dplyr::select(-"search"))
+      return(
+        search_df %>%
+          dplyr::select(-"search")
+      )
     }
   } else if (length(unique_search) > 1) {
-    if (overwrite_cache == TRUE | tw_check_cache(cache) == FALSE) {
+    if (overwrite_cache | !tw_check_cache(cache)) {
       pb <- progress::progress_bar$new(total = length(unique_search))
       search_df <- dplyr::left_join(
         x = tibble::tibble(search = search),
@@ -110,15 +138,17 @@ tw_search <- function(search,
         disconnect_db = disconnect_db
       )
 
-      if (include_search == TRUE) {
+      if (include_search) {
         return(search_df)
       } else {
-        return(search_df %>%
-          dplyr::select(-"search"))
+        return(
+          search_df %>%
+            dplyr::select(-"search")
+        )
       }
     }
 
-    if (overwrite_cache == FALSE & tw_check_cache(cache) == TRUE) {
+    if (!overwrite_cache & tw_check_cache(cache)) {
       search_from_cache_df <- tw_get_cached_search(
         search = unique_search,
         type = type,
@@ -130,7 +160,9 @@ tw_search <- function(search,
         disconnect_db = FALSE
       )
 
-      search_not_in_cache_v <- unique_search[!is.element(unique_search, search_from_cache_df$search)]
+      search_not_in_cache_v <- unique_search[
+        !is.element(unique_search, search_from_cache_df$search)
+      ]
 
       if (length(search_not_in_cache_v) == 0) {
         search_df <- dplyr::left_join(
@@ -144,11 +176,13 @@ tw_search <- function(search,
           disconnect_db = disconnect_db,
           language = language_combo
         )
-        if (include_search == TRUE) {
+        if (include_search) {
           return(search_df)
         } else {
-          return(search_df %>%
-            dplyr::select(-"search"))
+          return(
+            search_df %>%
+              dplyr::select(-"search")
+          )
         }
       } else if (length(search_not_in_cache_v) > 0) {
         pb <- progress::progress_bar$new(total = length(search_not_in_cache_v))
@@ -189,8 +223,7 @@ tw_search <- function(search,
           by = "search"
         )
 
-
-        if (include_search == TRUE) {
+        if (include_search) {
           search_merged_df
         } else {
           search_merged_df %>%
@@ -202,28 +235,32 @@ tw_search <- function(search,
 }
 
 
-
-#' Search for Wikidata items or properties and return Wikidata id, label, and description.
+#' Search for Wikidata items or properties and return Wikidata id, label, and
+#' description.
 #'
-#' This search returns only items, use `tw_search_property()` for properties.
+#' This search returns only items, use [tw_search_property()] for properties.
 #'
 #' @inheritParams tw_search
 #'
-#' @return A data frame (a tibble) with three columns (id, label, and description), and as many rows as there are results (by default, limited to 10). Four columns when `include_search` is set to TRUE.
+#' @return A data frame (a tibble) with three columns (`id`, `label`, and
+#'   `description`), and as many rows as there are results (by default, limited
+#'   to 10). Four columns when `include_search` is set to TRUE.
 #'
 #' @examples
 #' tidywikidatar:::tw_search_single(search = "Sylvia Pankhurst")
-tw_search_single <- function(search,
-                             type = "item",
-                             language = tidywikidatar::tw_get_language(),
-                             response_language = tidywikidatar::tw_get_language(),
-                             limit = 10,
-                             include_search = FALSE,
-                             cache = NULL,
-                             overwrite_cache = FALSE,
-                             cache_connection = NULL,
-                             disconnect_db = TRUE,
-                             wait = 0) {
+tw_search_single <- function(
+  search,
+  type = "item",
+  language = tidywikidatar::tw_get_language(),
+  response_language = tidywikidatar::tw_get_language(),
+  limit = 10,
+  include_search = FALSE,
+  cache = NULL,
+  overwrite_cache = FALSE,
+  cache_connection = NULL,
+  disconnect_db = TRUE,
+  wait = 0
+) {
   rlang::check_required(search)
   if (is.null(search)) {
     cli::cli_abort("A search string must be given.")
@@ -234,29 +271,39 @@ tw_search_single <- function(search,
   }
 
   if (length(search) > 1) {
-    cli::cli_abort(c("`search` must have length 1.", i = "Consider using `tw_search()`."))
+    cli::cli_abort(c(
+      x = "`search` must have length 1.",
+      i = "Consider using {.fn tw_search}."
+    ))
   }
 
   if (is.na(search)) {
-    if (include_search == TRUE) {
+    if (include_search) {
       return(tidywikidatar::tw_empty_search)
     } else {
-      return(tidywikidatar::tw_empty_search %>%
-        dplyr::select(-"search"))
+      return(
+        tidywikidatar::tw_empty_search %>%
+          dplyr::select(-"search")
+      )
     }
   }
 
   if (search == "") {
-    if (include_search == TRUE) {
+    if (include_search) {
       tidywikidatar::tw_empty_search %>%
         dplyr::add_row(search = "")
     } else {
-      return(tidywikidatar::tw_empty_search %>%
-        dplyr::select(-"search"))
+      return(
+        tidywikidatar::tw_empty_search %>%
+          dplyr::select(-"search")
+      )
     }
   }
 
-  language_combo <- stringr::str_c(language, "_", response_language)
+  language_combo <- stringr::str_flatten(
+    string = c(language, response_language),
+    collapse = "_"
+  )
 
   db <- tw_connect_to_cache(
     connection = cache_connection,
@@ -264,7 +311,7 @@ tw_search_single <- function(search,
     cache = cache
   )
 
-  if (tw_check_cache(cache) == TRUE & overwrite_cache == FALSE) {
+  if (tw_check_cache(cache) & !overwrite_cache) {
     db_result <- tw_get_cached_search(
       search = search,
       type = type,
@@ -283,17 +330,23 @@ tw_search_single <- function(search,
         language = language_combo
       )
 
-      return(db_result %>%
-        tibble::as_tibble())
+      return(
+        db_result %>%
+          tibble::as_tibble()
+      )
     }
   }
 
   Sys.sleep(time = wait)
 
   base_url <- "https://www.wikidata.org/w/api.php"
-  api_request <- httr2::request(base_url = base_url) |>
-    httr2::req_headers(`Accept-Encoding` = "gzip") |>
-    httr2::req_user_agent(string = stringr::str_c("tidywikidatar/", as.character(packageVersion("tidywikidatar")))) |>
+  api_request <- httr2::request(base_url = base_url) %>%
+    httr2::req_headers(`Accept-Encoding` = "gzip") %>%
+    httr2::req_user_agent(
+      string = stringr::str_flatten(
+        c("tidywikidatar/", as.character(packageVersion("tidywikidatar")))
+      )
+    ) %>%
     httr2::req_url_query(
       action = "wbsearchentities",
       type = type,
@@ -302,10 +355,10 @@ tw_search_single <- function(search,
       search = search,
       uselang = response_language,
       format = "json"
-    ) |>
-    httr2::req_error(is_error = \(resp) FALSE)
+    ) %>%
+    httr2::req_error(is_error = function(resp) FALSE)
 
-  response_json <- httr2::req_perform(api_request) |>
+  response_json <- httr2::req_perform(api_request) %>%
     httr2::resp_body_json()
 
   if (is.null(response_json[["error"]][["info"]]) == FALSE) {
@@ -314,29 +367,30 @@ tw_search_single <- function(search,
       i = "{response_json[['error']][['info']]}"
     ))
     search_response <- tibble::tibble(
-      id = as.character(NA),
-      label = as.character(NA),
-      description = as.character(NA)
+      id = NA_character_,
+      label = NA_character_,
+      description = NA_character_
     )
   } else {
-    search_response <- response_json |>
+    search_response <- response_json %>%
       purrr::pluck("search")
   }
 
   if (length(search_response) == 0) {
     search_response_df <- tibble::tibble(
-      id = as.character(NA),
-      label = as.character(NA),
-      description = as.character(NA)
+      id = NA_character_,
+      label = NA_character_,
+      description = NA_character_
     )
-  } else if (tibble::is_tibble(search_response) == TRUE) {
+  } else if (tibble::is_tibble(search_response)) {
     search_response_df <- search_response
   } else {
     search_response_df <- purrr::map_dfr(
       .x = search_response,
       .f = function(x) {
         extracted_label <- x %>% purrr::pluck("label", .default = NA_character_)
-        extracted_description <- x %>% purrr::pluck("description", .default = NA_character_)
+        extracted_description <- x %>%
+          purrr::pluck("description", .default = NA_character_)
 
         tibble::tibble(
           id = x %>% purrr::pluck("id"),
@@ -363,7 +417,7 @@ tw_search_single <- function(search,
       "description"
     )
 
-  if (tw_check_cache(cache) == TRUE) {
+  if (tw_check_cache(cache)) {
     tw_write_search_to_cache(
       search_df = search_response_df,
       type = type,
@@ -383,41 +437,45 @@ tw_search_single <- function(search,
     language = language_combo
   )
 
-  if (include_search == TRUE) {
+  if (include_search) {
     search_response_df %>%
-      dplyr::filter(is.na(.data$id) == FALSE) %>%
+      dplyr::filter(!is.na(.data$id)) %>%
       tibble::as_tibble()
   } else {
     search_response_df %>%
-      dplyr::filter(is.na(.data$id) == FALSE) %>%
+      dplyr::filter(!is.na(.data$id)) %>%
       dplyr::select(-"search") %>%
       tibble::as_tibble()
   }
 }
 
 
-
-#' Search for Wikidata properties in Wikidata and return Wikidata id, label, and description.
+#' Search for Wikidata properties in Wikidata and return Wikidata id, label, and
+#' description.
 #'
-#' This search returns only items, use `tw_search_property()` for properties.
+#' This search returns only items, use [tw_search_property()] for properties.
 #'
 #' @inheritParams tw_search
 #'
-#' @return A data frame (a tibble) with three columns (id, label, and description), and as many rows as there are results (by default, limited to 10).
+#' @return A data frame (a tibble) with three columns (`id`, `label`, and
+#'   `description`), and as many rows as there are results (by default, limited
+#'   to 10).
 #' @export
 #'
 #' @examples
 #' tw_search_item(search = "Sylvia Pankhurst")
-tw_search_item <- function(search,
-                           language = tidywikidatar::tw_get_language(),
-                           response_language = tidywikidatar::tw_get_language(),
-                           limit = 10,
-                           include_search = FALSE,
-                           wait = 0,
-                           cache = NULL,
-                           overwrite_cache = FALSE,
-                           cache_connection = NULL,
-                           disconnect_db = TRUE) {
+tw_search_item <- function(
+  search,
+  language = tidywikidatar::tw_get_language(),
+  response_language = tidywikidatar::tw_get_language(),
+  limit = 10,
+  include_search = FALSE,
+  wait = 0,
+  cache = NULL,
+  overwrite_cache = FALSE,
+  cache_connection = NULL,
+  disconnect_db = TRUE
+) {
   tw_search(
     search = search,
     type = "item",
@@ -434,28 +492,32 @@ tw_search_item <- function(search,
 }
 
 
-
-#' Search for Wikidata properties in Wikidata and return Wikidata id, label, and description.
+#' Search for Wikidata properties in Wikidata and return Wikidata id, label, and
+#' description.
 #'
-#' This search returns only properties, use `tw_search_items()` for properties.
+#' This search returns only properties, use [tw_search_item()] for properties.
 #'
 #' @inheritParams tw_search
 #'
-#' @return A data frame (a tibble) with three columns (id, label, and description), and as many rows as there are results (by default, limited to 10).
+#' @return A data frame (a tibble) with three columns (`id`, `label`, and
+#'   `description`), and as many rows as there are results (by default, limited
+#'   to 10).
 #' @export
 #'
 #' @examples
 #' tw_search_property(search = "gender")
-tw_search_property <- function(search,
-                               language = tidywikidatar::tw_get_language(),
-                               response_language = tidywikidatar::tw_get_language(),
-                               limit = 10,
-                               include_search = FALSE,
-                               wait = 0,
-                               cache = NULL,
-                               overwrite_cache = FALSE,
-                               cache_connection = NULL,
-                               disconnect_db = TRUE) {
+tw_search_property <- function(
+  search,
+  language = tidywikidatar::tw_get_language(),
+  response_language = tidywikidatar::tw_get_language(),
+  limit = 10,
+  include_search = FALSE,
+  wait = 0,
+  cache = NULL,
+  overwrite_cache = FALSE,
+  cache_connection = NULL,
+  disconnect_db = TRUE
+) {
   tw_search(
     search = search,
     type = "property",
